data {
  int<lower=0> N; // number of people 
  int<lower=0> nTrials; //total length of long list
  
  int lowerIdx[N];
  int basketSize[N]; //number of items within each basket
  
  vector[nTrials] itemVec; // true items
  vector[N] guessVec; //guesses
  
}

parameters {
  //parameters of interest
  real b1;
  real<lower=0 > exponent;
  real<lower=0> std;
 
}


transformed parameters {
   vector[N] pred; //estimated prediction
  
   //model predictions
   for(i in 1:N) {
        pred[i] = b1*sum(segment(itemVec,lowerIdx[i], basketSize[i]))^exponent; 
   }
}

model {

  //slope
  b1~cauchy(1, 5);
  
  //power function
  exponent ~ cauchy(1,5);

  //error
  std ~ cauchy(0,5);
  
  //likelihood
  for(i in 1:N) {
    log(guessVec[i]) ~ normal(log(pred[i]), std);
  }
}
  
generated quantities {
   //calculate log-likelihood
   vector[N] log_lik;
   for(i in 1:N)  log_lik[i] = normal_lpdf(log(guessVec[i])| log(pred[i]), std);
   
}

