data {
  int<lower=0> N; // number of people 
  int<lower=0> nTrials; //total length of long list
  
  int<lower=0> lowerIdx[N];
  int<lower=0> upperIdx[N];
  
  matrix[nTrials, 24] itemMatrix; // true items
  row_vector[24] dummyVec;
  real guessVec[nTrials]; //guesses
  
}

parameters {
  //parameters of interest
  real b1_mu;
  real b1[N];
  real<lower=0 > exponent[N];
  real<lower=0 > exponent_mu;

  real w1[N];
  real w1_mu;
 

 
  real<lower=0> sigma_b1;
  real<lower=0> sigma_exponent;
  real<lower=0> sigma_w1;

  real<lower=0> std[N];
 
}


transformed parameters {
   //interim variables
   real pred[nTrials]; //estimated prediction
   row_vector[24] weightVec[N];
   
   
   //model predictions
   for(i in 1:N) {
      
      weightVec[i]= b1[i]+w1[i]*dummyVec;//+w2[i]*dummySquared;
         
      for (s in lowerIdx[i]:upperIdx[i]) 
         pred[s] = pow(sum(weightVec[i].*itemMatrix[s]),exponent[i]);
   }
}

model {

  //intercept
  b1_mu ~ normal(1,5);
  sigma_b1 ~ cauchy(0,2);
  b1~normal(b1_mu, sigma_b1);
  
  //linear weight
  w1_mu~normal(0,5);
  sigma_w1 ~ cauchy(0,2);
  w1~normal(w1_mu,sigma_w1);

  //power function
  exponent_mu~normal(1,5);
  sigma_exponent ~ cauchy(0,2);
  exponent ~ normal(exponent_mu,sigma_exponent);

  //error
  std ~ cauchy(0,2);
  
  //likelihood
  for(i in 1:N) {
    for (s in lowerIdx[i]:upperIdx[i])
    log(guessVec[s]) ~ normal(log(pred[s]), std[i]);
  }
}
  
generated quantities {
   //calculate log-likelihood
   vector[nTrials] log_lik;
   for(i in 1:N) {
      for (s in lowerIdx[i]:upperIdx[i])
         
        log_lik[s] = normal_lpdf(log(guessVec[s])| log(pred[s]), std[i]);
   }
   
}
