data {
  int<lower=0> N; // number of people 
  int<lower=0> nTrials; //total length of long list
  
  int<lower=0> lowerIdx[N];
  int<lower=0> upperIdx[N];
  
  matrix[nTrials, 24] itemMatrix; // true items
  real guessVec[nTrials]; //guesses
  
}

parameters {
  //parameters of interest
  real b1_mu;
  real b1[N];
  real<lower=0 > exponent[N];
  real<lower=0 > exponent_mu;

  real<lower=0> sigma_b1;
  real<lower=0> sigma_exponent;
 
  real<lower=0> std[N];
 
}


transformed parameters {
   //interim variables
   real pred[nTrials]; //estimated prediction
  
   //model predictions
   for(i in 1:N) {
      
     for (s in lowerIdx[i]:upperIdx[i]) { 
         pred[s] = sum(b1[i]*exp(exponent[i]*log(itemMatrix[s])));
    
      }
   }
}

model {

  //intercept
  b1_mu ~ normal(1,5);
  sigma_b1 ~ cauchy(0,2);
  b1~normal(b1_mu, sigma_b1);
  
  //power function
  exponent_mu~normal(1,5);
  sigma_exponent ~ cauchy(0,2);
  exponent ~ normal(exponent_mu,sigma_exponent);

  //error
  std ~ cauchy(0,2);
  
  //likelihood
  for(i in 1:N) {
    for (s in lowerIdx[i]:upperIdx[i])
    log(guessVec[s]) ~ normal(log(pred[s]), std[i]);
  }
}
  
generated quantities {
   //calculate log-likelihood
   vector[nTrials] log_lik;
   for(i in 1:N) {
      for (s in lowerIdx[i]:upperIdx[i])
         
        log_lik[s] = normal_lpdf(log(guessVec[s])| log(pred[s]), std[i]);
   }
   
}
