plotPostPred = function (observed,stanFit, filename="myplot.pdf"){
  #plots the posterior predictive for all 40 participants on 5 pdf pages (8 plots per page, 4 rows, 2 colums)
  
  pdf(filename, width=8.5, height=11) #create pdf in letter format
  
  #observed=stanData$guessVec
  post     = extract(stanFit, pars = c("pred", "std"))
  pointpred= post$pred
  stdev    = post$std
  
  
  par(mfrow=c(4,3))
  for(vpn in 1:40){
    
    subSet         = lowerIdx[vpn]:upperIdx[vpn]
    this.pointPred = pointpred[,subSet]
    this.observed  = log(observed[subSet])
    
    #include likelihood function (std is on log scale)
    nTrials      = length(subSet)
    nJagsSamples = dim(pointpred)[1]
    
    this.pred = matrix(NA, nrow=nJagsSamples, ncol=nTrials)
    hpd95     = matrix(NA, nrow=2, ncol=nTrials)
    for(i in 1:nTrials){ 
      this.pred[,i] = rnorm(mean=log(this.pointPred[,i]), sd=stdev[,vpn], n=nJagsSamples)#exp(rnorm(mean=log(this.pointPred[,i]), sd=stdev[,vpn], n=nJagsSamples))
      hpd95[,i]     = HPDinterval(as.mcmc(this.pred[,i]))
    }
    
    
    plot(NULL, xlim=range(this.observed), ylim=range(this.pred), main=paste("Participant #",vpn), 
         xlab="observed value (log-scale)", ylab= "model prediction/ HPD95 (log-scale)", xaxt="n", yaxt="n", bty="l")
    abline(0,1, col="red")
    
    #add axis
    axisLabels=c(25, 50,100,200,400,800)
    axis(1, at=c(0,log(axisLabels)), labels=c(0,axisLabels))
    axis(2, at=c(0,log(axisLabels)), labels=c(0,axisLabels))
    
    for (i in 1:nTrials){
      arrows(x0=this.observed[i],x1=this.observed[i],y0=hpd95[1,i], y1=hpd95[2,i], angle=90, length=0, code=3)
      points(this.observed[i], median(this.pred[,i]), col="blue")
    }
 
    if(vpn%%12==0) par(mfrow=c(4,3))
  }
  dev.off()
}