plotWeighting = function(fit, dummyVec, addAxis=F){
#function to plot the  weighting vector
   
   library(coda)
   
   post <- extract(fit,permuted = TRUE, pars = c("b1_mu", 
                                                  "w1_mu", 
                                                  "w2_mu", 
                                                  "b1",
                                                  "w1",
                                                  "w2")) # return a list of arrays 

   b1_mu <- post$b1_mu
   w1_mu <- post$w1_mu
   w2_mu <- post$w2_mu

   xx=dummyVec
   
   #add individual vectors
   b1=post$b1
   w1=post$w1
   w2=post$w2


   #add equation
     b1.round=round(mean(b1_mu),2)
     w1.round=-1*round(mean(w1_mu),2)
     w2.round=-1*round(mean(w2_mu),2)
     
     equation=bquote(italic(w)==.(b1.round)-.(w1.round)%*%italic(s)-.(w2.round)%*%italic(s)^2)
     
     
   
   #construct weighting vector
   y=matrix(NA, nrow=n, ncol=length(xx))
   for(i in 1:n){
      y[i,]=mean(b1[,i]) + mean(w1[,i])*xx + mean(w2[,i])*xx^2 
   }
   
   yy=  mean(b1_mu) +  mean(w1_mu) * xx  +  mean(w2_mu) * xx^2 
   
   #calculate 95%credible interval
   y95=matrix(NA, nrow=length(xx), ncol=2)
   for(i in 1:length(xx)){
      
      this.y=  b1_mu +  w1_mu * xx[i] +  w2_mu * xx[i]^2 
      y95[i,]=HPDinterval(as.mcmc(as.vector(this.y)))
   }
   
   
   
   windows(6,6)
   par(mar=c(5.1, 5.1, 1.1, 1.1))
   yrange=range(c(1,y))
   plot(NULL,ylim=yrange, xlim=range(xx)   ,xlab=expression(paste("Serial position (", italic(s), ")")), 
        cex.axis=1.2, cex.lab=1.5,col="black",ylab=expression(paste("Weight ("         , italic(w), ")")), main="", xaxt="n")
   
   #add hpd95
   polygon(x=c(xx, rev(xx)), y=c(y95[,1], rev(y95[,2])),col='grey80', border=NA )
   
   abline(h=1, lwd=1, lty="dashed")
   
   #add individual data
   for(i in 1:n){
      points(xx,y[i,], type="l", col="grey40")
   }
   
   #add group-level data
   points(xx,yy,lwd=2.5, col="black", type="l" )
   points(xx,yy,cex=1.5, pch=21,lwd=1, bg="grey90")
   
   if(addAxis==T) {
     axis(1, at=xx, labels=(1:24), cex.axis=1.2) 
     } else {
       axis(1,at=xx, labels=F)
       axis(1,at=c(xx[1],xx[length(xx)]), labels=c("first", "last"), cex.axis=1.2)
     }
   
   
   #add equation text
   text(range(xx)[1], max(yrange), equation, cex=1.3, adj=0)
   
}
