#step1: Generate estimates from the sum-first and the power-first models respectively
#step2: Fit the simulated choice data with both models and check if the models can be recovered

#================#
# Lab study data #
#================#

load("labData.RData")
n=length(rawDatalist)


itemMatrix=NULL
guessVec=NULL
nValid=std=rep(NA, times=n)

for (i in 1:n) {
  
  this.rawData=rawDatalist[[i]]
  this.itemMatrix=data.matrix(this.rawData[,14:37]) #each row = one of 75 sequences
  this.Guess=this.rawData$geschtzter.Betrag  
  
  #sort itemMatrix and guesses based on the order in which they were presented
  sortIdx=order(this.rawData$originalOrder)
  this.itemMatrix=this.itemMatrix[sortIdx,]
  this.Guess=this.Guess[sortIdx]
  
  #optionally, only include the first or the last sequences
  firstQuintile=1:15
  lastQuintile=60:75
  
  #idx=lastQuintile
  #this.itemMatrix=this.itemMatrix[idx,]
  #this.Guess=this.Guess[idx]
  
  
  #optionally: identify and remove outliers (bias > 1)
  
  this.actual=rowSums(this.itemMatrix)      
  this.bias=(this.Guess-this.actual)/this.actual
  this.outlier=F#this.bias>1
  
  nOutliers=sum(this.outlier)
  nValid[i]=dim(this.itemMatrix)[1]-nOutliers
  
  if(nOutliers>0) {
    outlierPos=which(this.outlier==T)
    this.Guess=this.Guess[-outlierPos] 
    this.itemMatrix=this.itemMatrix[-outlierPos,]
  }
  
  std[i]=sd(log(this.Guess))
  #append data to long list
  itemMatrix=rbind(itemMatrix, this.itemMatrix)
  guessVec=c(guessVec, this.Guess)
  
  
}  



upperIdx=cumsum(nValid)
lowerIdx=(upperIdx-nValid)+1


#sum first and power first models
mSumFirst   = function (mm, params){ apply(t(params[1:24]*t(mm)), 1, sum)^params[25] }

mPowerFirst = function (mm, params){ apply(mm, 1, function(vec) {sum(params[1:24]*vec^params[25])})  }   


#Function to add noise to the simulated estimates
addNoise = function(vec, noise){
  lower=vec-1*vec*noise/2
  upper=vec+vec*noise/2
  
  noiseVec=runif(length(vec), min=lower, max=upper)
  if(any(noiseVec<=0)) print("Adding noise led to negative values. Consider adding less noise.")
  return(noiseVec)
  
}

#quadratic loss functions
loss.PowerFirst = function (params, mm, estimate){
  
  beta0=params[1]
  beta1=params[2]
  beta2=params[3]
  exponent=params[4]
  stdev=params[5]
  
  weightVec=beta0+beta1*(1:24)+beta2*(1:24)^2
  prediction=mPowerFirst(mm, c(weightVec,exponent))
  
  #log-log-likelihood (to account for heteroscedascidity)
  ll=dnorm(log(estimate), mean=log(prediction), sd=stdev)
  loss=-2*sum(log(ll))
  
  
  #likelihood
  #ll=dnorm(estimate, mean=prediction, sd=stdev)
  #loss=-2*sum(log(ll))
  
  return(loss)
}


loss.SumFirst = function (params, mm, estimate){
  
  beta0=params[1]
  beta1=params[2]
  beta2=params[3]
  exponent=params[4]
  stdev=params[5]
  
  weightVec=beta0+beta1*(1:24)+beta2*(1:24)^2
  prediction=mSumFirst(mm, c(weightVec,exponent))
  
  #log-log-likelihood (to account for heteroscedascidity)
  ll=dnorm(log(estimate), mean=log(prediction), sd=stdev)
  loss=-2*sum(log(ll))
  
  #log-likelihood
  #ll=dnorm(estimate, mean=prediction, sd=stdev)
  #loss=-2*sum(log(ll))
  
  return(loss)
}

#Function to compare fit of both models
returnFit = function(fit1,fit2){
  
  #g2 deviance: smaller loss = better fit
  g2.loss=c(fit1$objective, fit2$objective)
  
  #BIC
  k=length(fit1$par) #number of parameters (same for both models)
  n=75 #number of observations
  
  BIC1 =fit1$objective+k*log(n)
  BIC2 =fit2$objective+k*log(n)
  
  BF=exp((BIC2-BIC1)/2) #values >1 = evidence for model 1
  
  return(c(g2.diff=g2.loss[2]-g2.loss[1], 
           BICdiff=BIC2-BIC1,
           BF     =BF))
}




nRounds=20
resultMatrixSumFirst=resultMatrixPowerFirst=NULL
cat("*")
for (i in 1:nRounds){
  
  #progress bar
  percent5=nRounds/20
  if(i%%percent5==0) cat("*")
  
  #pick experimental stimuli 
  vpn=sample(1:n, size=1)
  items=itemMatrix[lowerIdx[vpn]:upperIdx[vpn],]
  

  #combination of parameters for this round
  noise=0.1
  exponent=runif(1,.7,.98)
  beta0=runif(1,0,2)
  beta1=runif(1,0,.1)
  beta2=runif(1,0,.01)

  #------
  # Step 1: Generate deterministic data from both models 
  weightVec=beta0+beta1*(1:24)+beta2*(1:24)^2
  
    params.Function=c(weightVec,exponent)
    estimateS=mSumFirst(mm=items, params.Function)
    estimateP=mPowerFirst(mm=items, params.Function)

  #------
  #Step 2: Add noise and fit both models to the data
 
  estimateS.noise=addNoise(estimateS,noise)
  estimateP.noise=addNoise(estimateP,noise)
  
  #--------------
  #fit PowerFirst
  fit.PowerFirst.pData=nlminb(start=c(1,1,.1,.1,20), objective=loss.PowerFirst, mm=items, estimate=estimateP.noise, lower=c(0,0,0,0, 0.0001), control=list(eval.max=1000, iter.max=1000))
  fit.PowerFirst.sData=nlminb(start=c(1,1,.1,.1,20), objective=loss.PowerFirst, mm=items, estimate=estimateS.noise, lower=c(0,0,0,0, 0.0001), control=list(eval.max=1000, iter.max=1000))

  
  #--------------
  #fit SumFirst
  fit.SumFirst.pData=nlminb(start=c(1,1,.1,.1,20), objective=loss.SumFirst, mm=items, estimate=estimateP.noise, lower=c(0,0,0,0, 0.0001), control=list(eval.max=1000, iter.max=1000))
  fit.SumFirst.sData=nlminb(start=c(1,1,.1,.1,20), objective=loss.SumFirst, mm=items, estimate=estimateS.noise, lower=c(0,0,0,0, 0.0001), control=list(eval.max=1000, iter.max=1000))
  
  #keep track of model recovery (positive BIC difference = model could be recovered)
  resultMatrixSumFirst  =rbind(resultMatrixSumFirst  ,c(beta0=beta0, beta1=beta1,exponent=exponent,noise=noise,returnFit(fit.SumFirst.sData,fit.PowerFirst.sData)))
  resultMatrixPowerFirst=rbind(resultMatrixPowerFirst,c(beta0=beta0, beta1=beta1,exponent=exponent,noise=noise,returnFit(fit.PowerFirst.pData,fit.SumFirst.pData)))
  
}

#-----------------------
#Summarize model recovery
#positive value = data-generating model can be distinguished
  boxplot(resultMatrixSumFirst[,"BICdiff"], main="Recovery of SumFirst Model", 
          ylab=expression(paste(Delta, "BIC")), col="lightblue")
  mtext(paste("p(sum first model better) =", round(mean(resultMatrixSumFirst[,"BICdiff"]>0),2)))

  boxplot(resultMatrixPowerFirst[,"BICdiff"], main="Recovery of PowerFirst Model", 
          ylab=expression(paste(Delta, "BIC")), col="lightgreen")
  mtext(paste("p(power first model better) =", round(mean(resultMatrixPowerFirst[,"BICdiff"]>0),2)))

