#
# fishing.R,  2 Oct 22
#
# Data from:
# The Psychophysics of Number Integration: Evidence From the Lab and From the Field
# Benjamin Scheibehenne


library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


load("Lab-Study/labData.RData")

plot(longFrame$guess, longFrame$actual, log="xy", col=pal_col[2],
	xlab="Estimated total value", ylab="Actual value")
lines(c(1, 1000), c(1, 1000), col="grey")

sch_mod=glm(log(actual) ~ log(guess), data=longFrame)
summary(sch_mod)

schv_mod=glm(log(actual) ~ log(guess)+verlauf+vpn, data=longFrame)
summary(schv_mod)

x_bounds=1:1000
pred=predict(sch_mod, newdata=data.frame(guess=x_bounds))

lines(x_bounds, exp(pred), col=pal_col[1])

g_cnt=count(longFrame$guess)
sg_cnt=g_cnt[order(g_cnt$freq, decreasing=TRUE), ]
top10=head(sg_cnt, n=15)

plot(g_cnt, col=pal_col[2], log="x",
	yaxs="i",
	xlab="Guess", ylab="Occurrences")
text(top10$x, top10$freq-3, top10$x, col="red")


shopData=read.csv(file="Field-Study/rawDataField.csv", as.is=TRUE)
load("Field-Study/bonList.RData")

# Warenwert Value of goods
# Schaetzung estimation
# KorbWagen basket cart
# Altersrange age range
# Einkaufsliste Shopping list
# Reihenfolge Series

# Check entries are in the same order (they are)
bl_value=sapply(bonList, sum)
# which(bl_value != shopData$Warenwert)
# t=which(bl_value != shopData$Warenwert)
# bl_value[t]-shopData$Warenwert[t]

shopData$nItems=sapply(bonList, length)

# Estimated total value of items in basket

plot(shopData$Schaetzung, shopData$Warenwert, log="xy", col=pal_col[2],
	xlab="Estimated total value", ylab="Actual value")
lines(c(1, 1000), c(1, 1000), col="grey")

shop_mod=glm(log(Warenwert) ~ log(Schaetzung), data=shopData)
summary(shop_mod)

# shopI_mod=glm(log(Warenwert) ~ log(Schaetzung)+log(nItems), data=shopData)
shopI_mod=glm(log(Warenwert) ~ log(Schaetzung)+Nguess+Einkaufsliste, data=shopData)
summary(shopI_mod)

pred=predict(shop_mod, newdata=data.frame(guess=x_bounds))

lines(x_bounds, exp(pred), col=pal_col[1])

# Estimate of number of items in basket

plot(shopData$Nguess, shopData$nItems, log="xy", col=pal_col[2],
		xlab="Estimated number of items", ylab="Actual items")
lines(c(1, 1000), c(1, 1000), col="grey")

# ei_mod=glm(nItems ~ Nguess, data=shopData)
ei_mod=glm(log(nItems) ~ log(Nguess), data=shopData)
summary(ei_mod)
pred=predict(ei_mod, newdata=data.frame(Nguess=1:100))

lines(1:100, exp(pred), col=pal_col[1])

t=count(shopData$nItems)
plot(t)

shop_cnt=count(shopData$Schaetzung)
plot(shop_cnt, log="x",
	xaxs="i", yaxs="i",
	ylim=c(0, 100))

sh_cnt=shop_cnt[order(shop_cnt$freq, decreasing=TRUE), ]
top10=head(sh_cnt, n=10)

text(top10$x, top10$freq-3, top10$x, col="red")


